/*
 * GRAL: GRAphing Library for Java(R)
 *
 * (C) Copyright 2009-2010 Erich Seifert <info[at]erichseifert.de>, Michael Seifert <michael.seifert[at]gmx.net>
 *
 * This file is part of GRAL.
 *
 * GRAL is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GRAL is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with GRAL.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.erichseifert.gral.io;

import java.util.Collections;
import java.util.HashSet;
import java.util.Set;

/**
 * Abstract class that implements the basic functions of a writer.
 */
public abstract class IOCapabilitiesStorage {
	private static final Set<IOCapabilities> capabilities = new HashSet<IOCapabilities>();

	/**
	 * Creates a new AbstractWriter object.
	 */
	protected IOCapabilitiesStorage() {
	}

	/**
	 * Returns a Set with IOCapabilities for all supported formats.
	 * @return IOCapabilities.
	 */
	public static Set<IOCapabilities> getCapabilities() {
		return Collections.unmodifiableSet(capabilities);
	}

	/**
	 * Adds the specified IOCapabilities to the Set of supported formats.
	 * @param capabilities IOCapabilities to be added.
	 */
	protected final static void addCapabilities(IOCapabilities capabilities) {
		IOCapabilitiesStorage.capabilities.add(capabilities);
	}
}
